gnucash maint: Multiple changes pushed

Robert Fewell bobit at code.gnucash.org
Sun Jul 17 06:41:56 EDT 2022


Updated	 via  https://github.com/Gnucash/gnucash/commit/d688a17e (commit)
	 via  https://github.com/Gnucash/gnucash/commit/1852b078 (commit)
	 via  https://github.com/Gnucash/gnucash/commit/625d1c06 (commit)
	 via  https://github.com/Gnucash/gnucash/commit/a19b5ef3 (commit)
	 via  https://github.com/Gnucash/gnucash/commit/cfc6e9d7 (commit)
	from  https://github.com/Gnucash/gnucash/commit/85af9156 (commit)



commit d688a17ef6dd23e6c1c35a75e52d4e27658d319e
Merge: 85af91569 1852b0785
Author: Robert Fewell <14uBobIT at gmail.com>
Date:   Sun Jul 17 11:31:54 2022 +0100

    Merge 'luzpaz' branch 'source-typos' into maint PR #1364


commit 1852b0785e89b9494f16b5ec81353a5ede2a9419
Author: luz paz <luzpaz at pm.me>
Date:   Mon Jun 27 07:19:35 2022 -0400

    Fix source typo makro->macro

diff --git a/gnucash/gnome/dialog-lot-viewer.c b/gnucash/gnome/dialog-lot-viewer.c
index 929bdf36d..ae237c4a8 100644
--- a/gnucash/gnome/dialog-lot-viewer.c
+++ b/gnucash/gnome/dialog-lot-viewer.c
@@ -513,7 +513,7 @@ gnc_split_viewer_fill (GNCLotViewer *lv, GtkListStore *store, SplitList *split_l
         gnc_commodity *currency;
         Transaction *trans = xaccSplitGetParent (split);
         time64 date = xaccTransGetDate (trans);
-        gnc_numeric amnt, valu, gains;
+        gnc_numeric amnt, value, gains;
 
         /* Do not show gains splits, however do show empty business splits */
         if (!is_business_lot && gnc_numeric_zero_p (xaccSplitGetAmount(split))) continue;
@@ -541,13 +541,13 @@ gnc_split_viewer_fill (GNCLotViewer *lv, GtkListStore *store, SplitList *split_l
          * For non-business accounts which are part of a lot,
          * invert the sign on the first. */
         currency = xaccTransGetCurrency (trans);
-        valu = xaccSplitGetValue (split);
+        value = xaccSplitGetValue (split);
         if (lv->selected_lot && !is_business_lot && (node != split_list))
-                valu = gnc_numeric_neg (valu);
-        xaccSPrintAmount (valbuff, valu,
+                value = gnc_numeric_neg (value);
+        xaccSPrintAmount (valbuff, value,
                           gnc_commodity_print_info (currency, TRUE));
         gtk_list_store_set (store, &iter, SPLIT_COL_VALUE, valbuff, -1);
-        gtk_list_store_set (store, &iter, SPLIT_COL_VALUE_DOUBLE, gnc_numeric_to_double (valu), -1);
+        gtk_list_store_set (store, &iter, SPLIT_COL_VALUE_DOUBLE, gnc_numeric_to_double (value), -1);
 
         /* Gains. Blank if none. */
         gains = xaccSplitGetCapGains (split);

commit a19b5ef342b693bd1862f3bb80e64c64c0b2276c
Author: luz paz <luzpaz at pm.me>
Date:   Mon Jun 27 07:17:44 2022 -0400

    Fix source typo reponse->response

diff --git a/gnucash/gnome-utils/dialog-totd.c b/gnucash/gnome-utils/dialog-totd.c
index 706b23455..48d10fd1e 100644
--- a/gnucash/gnome-utils/dialog-totd.c
+++ b/gnucash/gnome-utils/dialog-totd.c
@@ -45,7 +45,7 @@
 #define GNC_RESPONSE_BACK    2
 
 /* Callbacks */
-void gnc_totd_dialog_response_cb (GtkDialog *dialog, gint reponse, gpointer user_data);
+void gnc_totd_dialog_response_cb (GtkDialog *dialog, gint response, gpointer user_data);
 void gnc_totd_dialog_startup_toggled_cb (GtkToggleButton *button, gpointer user_data);
 
 /* The Tips */

commit cfc6e9d7e00eacaff7544784636617ffc66a6b3a
Author: luz paz <luzpaz at pm.me>
Date:   Mon Jun 27 07:16:54 2022 -0400

    Fix source typo begining->beginning

diff --git a/libgnucash/backend/xml/test/test-load-xml2.cpp b/libgnucash/backend/xml/test/test-load-xml2.cpp
index 64aa30a29..5325b2948 100644
--- a/libgnucash/backend/xml/test/test-load-xml2.cpp
+++ b/libgnucash/backend/xml/test/test-load-xml2.cpp
@@ -59,7 +59,7 @@ extern "C"
 #define GNC_LIB_REL_PATH "xml"
 
 static void
-remove_files_pattern (const char* begining, const char* ending)
+remove_files_pattern (const char* beginning, const char* ending)
 {
 }
 



Summary of changes:
 contrib/gnuc2ooo.py                            | 20 ++++++++++----------
 gnucash/gnome-utils/dialog-totd.c              |  2 +-
 gnucash/gnome/dialog-lot-viewer.c              | 10 +++++-----
 libgnucash/backend/xml/test/test-load-xml2.cpp |  2 +-
 4 files changed, 17 insertions(+), 17 deletions(-)



More information about the gnucash-changes mailing list
diff --git a/contrib/gnuc2ooo.py b/contrib/gnuc2ooo.py
index 9eaeadcc0..37aa3ab94 100644
--- a/contrib/gnuc2ooo.py
+++ b/contrib/gnuc2ooo.py
@@ -1,14 +1,14 @@
 #**********************************************************************
 #   Gnu Cash to OpenOffice.org (gnuc2ooo.py)
 #   
-#   Makros for the download of GnuCash Data to OpenOffice.org Base
+#   Macros for the download of GnuCash Data to OpenOffice.org Base
 #
-#   Makro SetGnuCashFilePaths:
+#   Macro SetGnuCashFilePaths:
 #       Set or change the filepaths of the (GnuCash) data source
 #       and of the new OpenOffice.org database that will be created
 #       in this makro though still empty
 #
-#   Makro fillGnuCashDB:
+#   Macro fillGnuCashDB:
 #       Download data from the GnuCash data source to OpenOffice.org
 #       Base
 #   
@@ -35,7 +35,7 @@
 #
 #**********************************************************************
 #   Acknowledgements: Special thanks go to the authors on OpenOffice.org
-#   makro programming Roberto Benitez(http://www.baseprogramming.com) and
+#   macro programming Roberto Benitez(http://www.baseprogramming.com) and
 #   Andrew Pitonyak (http://www.pitonyak.org)
 #**********************************************************************
 #   Changes
@@ -85,8 +85,8 @@ PathSettings = smgr.createInstanceWithContext(
 # ************************** PROLOG ***************************************
 from com.sun.star.ui.dialogs.TemplateDescription import FILEOPEN_SIMPLE, FILESAVE_AUTOEXTENSION
 lcodec = locale.getdefaultlocale()[1]
-set_makro = "SetGnuCashFilePaths"
-settings_textentrance = "#This file was generated by OpenOfficeMakro: "
+set_macro = "SetGnuCashFilePaths"
+settings_textentrance = "#This file was generated by OpenOfficeMacro: "
 settings_textinp = "GnuCashDatafile: "
 settings_textoutp = "Registered Database in Openoffice.org: "
 # Trace / Error - Information
@@ -178,7 +178,7 @@ def exec_SetGnuCashFilePaths():
     else:
         return None
     settings = open(settings_filepath(), 'w')
-    entrance_line = settings_textentrance + set_makro + '\n'
+    entrance_line = settings_textentrance + set_macro + '\n'
     settings.write(entrance_line)
     settings.write(settings_textinp)
     settings.write(GCFile.encode(lcodec) + '\n')
@@ -194,7 +194,7 @@ def exec_SetGnuCashFilePaths():
     settings.close()
     
     MessageBox('A new Openoffice.org database has been created.\n' +
-               'To fill with data please run makro "fillGnuCashDB."',
+               'To fill with data please run macro "fillGnuCashDB."',
                MsgType="infobox")  
 
 def read_filepaths():
@@ -630,7 +630,7 @@ def exec_fillGnuCashDB():
     filepaths = read_filepaths()
     if not filepaths:
         MessageBox('Reading filepaths not successful.\n' +
-            'Please run makro ' + '"' + set_makro + '"', MsgType="errorbox")
+            'Please run macro ' + '"' + set_macro + '"', MsgType="errorbox")
         return False
         
     gcfile = filepaths[0]
@@ -1,14 +1,14 @@
 #       Set or change the filepaths of the (GnuCash) data source
 #       and of the new OpenOffice.org database that will be created
-#       in this makro though still empty
+#       in this macro though still empty
 #

commit 625d1c063e3f9d29258f517f8cb23bf2c9115033
Author: luz paz <luzpaz at pm.me>
Date:   Mon Jun 27 07:19:04 2022 -0400

    Fix source typo valu->value
